Learn R Programming

pixr (version 0.1.0)

pix_endpoints: Get Available PIX API Endpoints

Description

Returns information about all available endpoints in the BCB PIX Open Data API.

Usage

pix_endpoints()

Arguments

Value

A tibble::tibble with endpoint names, descriptions, parameters, and associated functions.

Examples

Run this code
pix_endpoints()

Run the code above in your browser using DataLab