powered by
Returns information about all available endpoints in the BCB PIX Open Data API.
pix_endpoints()
A tibble::tibble with endpoint names, descriptions, parameters, and associated functions.
Run the code above in your browser using DataLab